from setuptools import find_namespace_packages, setup  # type: ignore

setup(name="pymbse", packages=find_namespace_packages(include=["pymbse.*"]))
